@@ -17,15 +17,15 @@ def _init_obj_wrapper(fn):
     def new(self, *args, **kw):
         if not self.obj:
             self.obj = self.s.getObject(self.id)
+            self.uri = self.obj.uri
         return fn(self, *args, **kw)
     return new
 
 class StoredEntity(Entity):
-    def init(self, id=None, storageclient=None, queue=None, context = None):
+    def init(self, id=None, storageclient=None, **context):
         self.id = id
         self.s = storageclient
         self.obj = None
-        self.queue = queue
         self.context = context
         self.revert()
 
@@ -34,8 +34,6 @@ class StoredEntity(Entity):
         self.store_root()
         self.store_manifest()
         self.store_parts()
-        if self.queue:
-            self.log('w', 'commit')
 
     @_init_obj_wrapper
     def list_parts(self):
@@ -48,15 +46,11 @@ class StoredEntity(Entity):
     @_init_obj_wrapper
     def del_part_version(self, part_id, version):
         r = self.obj.del_part_version(part_id, version)
-        if self.queue:
-            self.log('d','version', part_id=part_id, version=version)
         return r
 
     @_init_obj_wrapper
     def del_part_versions(self, part_id, versions, force=False):
         r = self.obj.del_part_versions(part_id, versions, force)
-        if self.queue:
-            self.log('d','versions', part_id=part_id, versions=versions)
         return r
 
     @_init_obj_wrapper
@@ -71,15 +65,12 @@ class StoredEntity(Entity):
     def revert(self, create_if_nonexistent=True):
         self.load_root(create_if_nonexistent)
         self.load_manifest(create_if_nonexistent)
-        self.add_namespace('local', self.s.uri_base)
 
     @_init_obj_wrapper
     def store_root(self):
         # only store the root if it has changed:
         if self.root.altered:
             self.obj.putRoot(self.root)
-        if self.queue:
-            self.log('w','root')
 
     @_init_obj_wrapper
     def load_root(self, create_if_nonexistent=True):
@@ -93,8 +84,6 @@ class StoredEntity(Entity):
         self.add_triple(part_uri, "dcterms:isPartOf", self.uri)
         if commit_metadata_changes:
             self.commit()
-        if self.queue:
-            self.log('w','stream', part_id=part_id)
 
     @_init_obj_wrapper
     def del_stream(self, part_id, commit_metadata_changes=False):
@@ -108,21 +97,15 @@ class StoredEntity(Entity):
             pass
         if commit_metadata_changes:
             self.commit()
-        if self.queue:
-            self.log('d','stream', part_id=part_id)
 
     @_init_obj_wrapper
     def get_stream(self, part_id, version=None):
         stream = self.obj.get_part(part_id, stream=True, version=version)
-        if self.queue:
-            self.log('r','stream', part_id=part_id)
         return stream
 
     @_init_obj_wrapper
     def get_as_bytes(self, part_id, version=None):
         stream = self.obj.get_part(part_id, stream=False, version=version)
-        if self.queue:
-            self.log('r','stream', part_id=part_id)
         return stream
 
     @_init_obj_wrapper
@@ -133,16 +116,12 @@ class StoredEntity(Entity):
                 self.obj.add_part(part_id, self.parts_objs[part_uri].to_string())
                 self.add_triple(self.uri, "ore:aggregates", part_uri)
                 self.add_triple(part_uri, "dcterms:isPartOf", self.uri)
-                if self.queue:
-                    self.log('w','part', part_id=part_id)
 
     @_init_obj_wrapper
     def store_manifest(self):
         # only store the manifest if it has changed:
         if self.manifest.altered:
             self.obj.putManifest(self.manifest)
-            if self.queue:
-                self.log('w','manifest')
 
     @_init_obj_wrapper
     def load_manifest(self, create_if_nonexistent=True):
@@ -169,12 +148,8 @@ class StoredEntity(Entity):
             g = super(StoredEntity, self).add_named_graph(graph_id, valid_from=valid_from, valid_until=valid_until)
             self.obj.add_part(graph_id, g.to_string())
             self.commit()
-            if self.queue:
-                self.log('w','namedgraph', namedgraph_id=graph_id)
             return g
         else:
-            if self.queue:
-                self.log('w','namedgraph', namedgraph_id=graph_id)
             return self.parts_objs[graph_uri]
 
     @_init_obj_wrapper
@@ -182,19 +157,4 @@ class StoredEntity(Entity):
         super(StoredEntity, self).del_named_graph(graph_id)
         self.obj.del_part(graph_id)
         self.commit()
-        if self.queue:
-            self.log('d','namedgraph', namedgraph_id=graph_id)
-
-    def log(self, action, label, **kw):
-        msg = {}
-        msg.update(kw)
-        msg.update(self.context)
-        msg['_id'] = self.id
-        msg['_action'] = action
-        msg['_label'] = label
-        msg['_uri_base'] = self.s.uri_base
-        try:
-            self.queue.put(simplejson.dumps(msg))
-        except Exception, e:
-            print "Logging failed"
 
