@@ -18,13 +18,20 @@ from rdfobject.stores.storage_exceptions import *
 
 from rdfobject.stores import StoreAlreadyExistsException
 
+class FakeQueue(object):
+    def put(self, msg):
+        print "FROM THE MQ: %s" % msg
+
+fq = FakeQueue()
 
 f = FileMultiEntityFactory()
 
 print f.status
-foo = f.add_store('foo', 'info:media/')
+foo = f.add_store('foo', 'info:media/', queue=fq)
 
-vid = foo.get('info:media/video:1')
+#vid = foo.get('info:media/video:1')
+
+vid = foo.get_id('video:1')
 
 vid.add_triple(vid.uri, 'dc:title', 'My Video Diary')
 vid.add_triple(vid.uri, 'dc:description', 'Boring video')
